from enum import StrEnum


class Language(StrEnum):
    PYTHON = "python"
    RUBY = "ruby"
    PHP = "php"
    JAVA = "java"
    GOLANG = "go"
    NEXTJS = "nextjs"
    NODEJS = "node"
    RUST = "rust"
    WORDPRESS = "wordpress"
    CSHARP = "csharp"
    ERLANG = "erlang"
    FLUTTER = "flutter"
    SWIFT = "swift"
    ACTIONS = "actions"  # Github Actions
